'''
Copyright (c)2022 - Soffos.ai - All rights reserved
Created at: 2023-06-26
Purpose: Easily use Contradiction Detection Service
-----------------------------------------------------
'''
from .service import SoffosAIService, inspect_arguments
from soffosai.common.constants import ServiceString


class ContradictionDetectionService(SoffosAIService):
    '''
    This module finds conflicting information in a body of text and returns a 
    description of the contradiction along with the relevant sentences and their 
    offsets within the original text.
    '''

    def __init__(self,  **kwargs) -> None:
        service = ServiceString.CONTRADICTION_DETECTION
        super().__init__(service, **kwargs)

    def __call__(self, user:str, text:str)->dict:
        payload = inspect_arguments(self.__call__, user, text)
        return super().__call__(payload)



from .service_io import ServiceIO
from ..constants import ServiceString


class ReviewTaggerIO(ServiceIO):
    service = ServiceString.REVIEW_TAGGER
    required_input_fields = ["text"]
    input_structure = {
        "text": str
    }
    output_structure = {
        "object": str,
        "action": str,
        "fault": str
    }



from .node import Node
from soffosai.core.services import inspect_arguments, TranscriptCorrectionService


class TranscriptCorrectionNode(Node):
    '''
    Transcript Correction Service configuration for Pipeline Use
    '''
    def __init__(self, name:str, text:str):
        source = inspect_arguments(self.__init__, name, text)
        service = TranscriptCorrectionService
        super().__init__(name, service, source)
